#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%global skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-lazy-object-proxy%{psuffix}
Version:        1.9.0
Release:        1.3
Summary:        Rebuild a new abstract syntax tree from Python's ast
License:        BSD-2-Clause
Group:          Development/Libraries/Python
URL:            https://github.com/ionelmc/python-lazy-object-proxy
Source:         https://files.pythonhosted.org/packages/source/l/lazy-object-proxy/lazy-object-proxy-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools >= 45}
BuildRequires:  %{python_module setuptools_scm >= 6.2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Obsoletes:      python-lazy_object_proxy < %{version}-%{release}
Provides:       python-lazy_object_proxy = %{version}-%{release}
%if %{with test}
BuildRequires:  %{python_module lazy-object-proxy = %{version}}
BuildRequires:  %{python_module pytest-benchmark}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
A fast and thorough lazy object proxy that rebuilds a new abstract syntax tree
from Python's ast

%prep
%setup -q -n lazy-object-proxy-%{version}

%build
%if !%{with test}
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build
%endif

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%endif

%if %{with test}
%check
%pytest tests
%endif

%if !%{with test}
%files %{python_files}
%doc AUTHORS.rst CHANGELOG.rst CONTRIBUTING.rst README.rst docs
%license LICENSE
%{python_sitearch}/lazy_object_proxy
%{python_sitearch}/lazy_object_proxy-%{version}*-info
%endif

%changelog
* Fri May  5 2023 Dirk Müller <dmueller@suse.com>
- update to 1.9.0:
  * Added support for matrix multiplication operator (``@``).
  * Should have all the wheels now (including the manylinux
    ones).
  * Bumped minimum version requirements for setuptools and
    setuptools-scm.
  * Switched the default pure python fallback implementation to
    the "simple" one (when you ``from lazy_object_proxy import
    Proxy`` and the C extension is not available).
    Previously the "slots" implementation was used but as it
    turns out it is slower on Python 3.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.8.0
  Cleaned up use of cPickle. Contributed by Sandro Tosi in #62.
  Cleaned up more dead Python 2 code.
  Added Python 3.11 wheels.
  Dropped support for Python 3.6.
* Thu Aug 18 2022 Ben Greiner <code@bnavigator.de>
- Clean specfile, remove code coverage check and travis-fold
* Sat Mar 26 2022 Dirk Müller <dmueller@suse.com>
- update to 1.7.1:
  * Removed most of the Python 2 support code and fixed ``python_requires`` to
    require at least Python 3.6.
  * Note that 1.7.0 has been yanked because it could not install on Python 2.7.
  * Switched CI to GitHub Actions, this has a couple consequences:
  * Fixed ``__index__`` to fallback to ``int`` if the wrapped object doesn't
    have an ``__index__`` method.  This prevents situations where code using a
    proxy would otherwise likely just call ``int`` had the object not have an
    ``__index__`` method.
* Wed Oct 13 2021 Ben Greiner <code@bnavigator.de>
- Unpin setuptools_scm<6.0 limit
* Sat Jul 31 2021 Dirk Müller <dmueller@suse.com>
- update to 1.6.0:
  * Added support for async special methods (``__aiter__``, ``__anext__``,
    ``__await__``, ``__aenter__``, ``__aexit__``).
    These are used in the ``async for``, ``await` and ``async with`` statements.
    Note that ``__await__`` returns a wrapper that tries to emulate the crazy
    stuff going on in the ceval loop, so there will be a small performance overhead.
  * Added the ``__resolved__`` property. You can use it to check if the factory has
    been called.
* Fri Feb 26 2021 Markéta Machová <mmachova@suse.com>
- Drop broken %%ifpython3 macro
* Sun Dec 20 2020 Dirk Müller <dmueller@suse.com>
- update to 1.5.2:
  * Added Python 3.9 wheels.
  * Removed Python 2.7 Windows wheels
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- udpate to 1.5.1:
  * Added ARM64 wheels (manylinux2014).
  * Added support for ``__fspath__``.
  * Dropped support for Python 3.4.
* Wed Apr 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.4.3
  * Added binary wheels for Python 3.8.
  * Fixed license metadata.
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.2:
  * Included a pyproject.toml to allow users install the sdist with old
    python/setuptools, as the setuptools-scm dep will be fetched by pip
    instead of setuptools. Fixes #30.
* Thu Jun 20 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.4.1
  * Fixed __mod__ for the slots backend.
  * Dropped support for Python 2.6 and 3.3.
  * Fixed wheels being built with -coverage cflags. No more issues
    about bogus cext.gcda files.
  * Removed useless C file from wheels.
  * Changed setup.py to use setuptools-scm.
- launch tests using multibuild
* Mon Jul 30 2018 sean.marlow@suse.com
- Update to v1.3.1
  + Fix broken release (sdist had a broken MANIFEST.in).
- Update to v1.3.0
  + Speed up arithmetic operations involving cext.Proxy subclasses.
* Sat May  6 2017 toddrme2178@gmail.com
- Don't provide python2-lazy_object_proxy, singlespec packages
  should use correct name.
* Mon Feb 27 2017 jmatejek@suse.com
- update for singlespec
- renamed to lazy-object-proxy for PyPI consistency
- updated download url
* Mon Jul  4 2016 arun@gmx.de
- update to version 1.2.2:
  * Added `manylinux <https://www.python.org/dev/peps/pep-0513/>`_
    wheels.
  * Minor cleanup in readme.
* Sun May 15 2016 tchvatal@suse.com
- Move from python2 to work with python3-astrid
* Tue Feb 23 2016 bwiedemann@suse.com
- fix license string
* Wed Feb 10 2016 michael@stroeder.com
- initial packaging of upstream release 1.2.1
